@@ -12,6 +12,8 @@ from sklearn.cross_decomposition import PLSRegression as PLS_sklearn
 from sklearn.decomposition import PCA as PCA_sklearn
 from sklearn.utils.validation import check_is_fitted
 
+from .plots import loadings_plot, score_plot, spe_plot, t2_plot
+
 epsqrt = np.sqrt(np.finfo(float).eps)
 
 
@@ -250,8 +252,11 @@ class PCA(PCA_sklearn):
             scaling_factor_for_scores=self.scaling_factor_for_scores,
             n_rows=self.N,
         )
-
         self.T2_limit = partial(T2_limit, n_components=self.n_components, n_rows=self.N)
+        self.SPE_plot = partial(spe_plot, model=self)
+        self.T2_plot = partial(t2_plot, model=self)
+        self.loadings_plot = partial(loadings_plot, model=self, loadings_type="p")
+        self.score_plot = partial(score_plot, model=self)
 
         return self
 
@@ -739,6 +744,10 @@ class PLS(PLS_sklearn):
         )
 
         self.T2_limit = partial(T2_limit, n_components=self.n_components, n_rows=self.N)
+        self.SPE_plot = partial(spe_plot, model=self)
+        self.T2_plot = partial(t2_plot, model=self)
+        self.loadings_plot = partial(loadings_plot, model=self)
+        self.score_plot = partial(score_plot, model=self)
 
         return self
 
